import { slash, removeLeadingForwardSlash } from "../../path.js";
function vitePluginExternalize() {
  const MODULE_ID = `astro:content`;
  const VIRTUAL_MODULE_ID = `\0${MODULE_ID}`;
  return {
    name: "@astro/plugin-externalize",
    enforce: "pre",
    resolveId(id) {
      if (id === MODULE_ID) {
        return { id: VIRTUAL_MODULE_ID, external: true };
      }
    },
    renderChunk(code, chunk) {
      if (chunk.imports.find((name) => name === VIRTUAL_MODULE_ID)) {
        const steps = removeLeadingForwardSlash(slash(chunk.fileName)).split("/").length - 1;
        const prefix = "../".repeat(steps) || "./";
        return code.replaceAll(VIRTUAL_MODULE_ID, `${prefix}content/.entry.mjs`);
      }
    }
  };
}
function pluginExternalize() {
  return {
    targets: ["server", "content"],
    hooks: {
      "build:before": () => {
        return {
          vitePlugin: vitePluginExternalize()
        };
      }
    }
  };
}
export {
  pluginExternalize,
  vitePluginExternalize
};
